# SFDL Cluster

This package provides utilities for clustering data using KMeans with optimal `k` selection based on Calinski-Harabasz score, and distributing data into clients with "Same Features, Different Label" skew.
